@@ -85,6 +85,7 @@ my %default_config = (
     history_height => 10,
 
     command             => q{},
+    hide_menu           => 0,
     max_host_menu_items => 30,
 
     macros_enabled   => 'yes',
@@ -98,12 +99,11 @@ my %default_config = (
     menu_send_autotearoff          => 0,
     menu_host_autotearoff          => 0,
 
+    unique_servers    => 0,
     use_all_a_records => 0,
 
     send_menu_xml_file => $ENV{HOME} . '/.clusterssh/send_menu',
 
-    shell_expansion => "/bin/bash -c 'shopt -s extglob\n echo %items%'",
-
     # don't set username here as takes precendence over ssh config
     user => '',
 );
